#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.3.0.0
visibility:           public
id:                   haskell-language-server-2.3.0.0-IyhyhkQMkBs64gRtOCzARw
key:                  haskell-language-server-2.3.0.0-IyhyhkQMkBs64gRtOCzARw
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  1c73f9afd2b4e823ac3523c60b4cb93e
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.3.0.0-IyhyhkQMkBs64gRtOCzARw
depends:
    aeson-pretty-0.8.10-LwfeurpuORQ8Y1EGo7TVYq
    async-2.2.6-Gml4H6UctygFSqCTsp1iZf base-4.18.2.1
    base16-bytestring-1.0.2.0-31yUxkNIVeJ6WQ1ftMFCcb
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-Dr7tkgtlkwAD12N9xZyl0y
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    extra-1.7.16-COAoMleqge7G93j2zK3Os3 filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.3.0.0-CuskZ5doPqZEn0YfuqNbaw
    githash-0.1.6.3-3EPyTzg4LKQI7CrdYLMav3
    hie-bios-0.12.0-eEsgx7XPeoA9QoerKf3NJ
    hiedb-0.4.3.0-Fwuou394YkhHgRNX5gRWe7
    hls-alternate-number-format-plugin-2.3.0.0-2hpnAnS0IX7AChx30Mf13O
    hls-cabal-fmt-plugin-2.3.0.0-6yWSxiSqUmXHFUtNRTrSrM
    hls-cabal-plugin-2.3.0.0-FBKoXXxg6Mz7ldtBrVXiKl
    hls-call-hierarchy-plugin-2.3.0.0-Gquj0iHWFrMKH6cdP7BSDX
    hls-change-type-signature-plugin-2.3.0.0-4hx6D2mKl0WGKyDz0cueoE
    hls-class-plugin-2.3.0.0-7Hpok2ktH7HJZn3v6MvC5w
    hls-code-range-plugin-2.3.0.0-K8SJDJaHMi5DkJA4KLx9yH
    hls-eval-plugin-2.3.0.0-JjS7iX37RQQ471bKAkDI6t
    hls-explicit-fixity-plugin-2.3.0.0-BV5tHYQMBLh7uDDi1TMuhI
    hls-explicit-imports-plugin-2.3.0.0-J4Y1wcUCB6IJzRmPJZ2OaY
    hls-explicit-record-fields-plugin-2.3.0.0-UxgyE0mYVkFxVy9ZEYCAI
    hls-fourmolu-plugin-2.3.0.0-D5UwMZcBT6w7CE2T4Y1tAp
    hls-gadt-plugin-2.3.0.0-IXYMrCWe92SDmlXOSoEvrc
    hls-graph-2.3.0.0-EYGUDAW4G45GWbQeWL4PMJ
    hls-hlint-plugin-2.3.0.0-2dN3m6LeSdW9z3pZeNthlw
    hls-module-name-plugin-2.3.0.0-4HmzX5y7NgtJb1HyKnQnwy
    hls-ormolu-plugin-2.3.0.0-8cG5udedE4I3aqxWgBBE2l
    hls-overloaded-record-dot-plugin-2.3.0.0-39TnRuuGunXFBUDTgW6hmS
    hls-plugin-api-2.3.0.0-8Ujn3HTyY0u7RJd0JNRS4G
    hls-pragmas-plugin-2.3.0.0-4ZF7iNtre4m7pnbkhOR2Jt
    hls-qualify-imported-names-plugin-2.3.0.0-CvAw14NLIZD2RXzqVJzHaT
    hls-refactor-plugin-2.3.0.0-8YpG9YfXYtUENX43AxGmqW
    hls-rename-plugin-2.3.0.0-3VW1cmiVqF4285QEjCKvgm
    hls-retrie-plugin-2.3.0.0-2CWHm0XTuWjHliM289QxEO
    hls-splice-plugin-2.3.0.0-4CpZReb3BzN3srg5NhCBdU
    hls-stylish-haskell-plugin-2.3.0.0-3BbqwyeaHvdqindgKYzB5
    lsp-2.2.0.0-IU5LfR6i0seFHTgeRVBnGx
    optparse-applicative-0.18.1.0-3oCCN3996F8HtRiEC4P5yD
    optparse-simple-0.1.1.4-HmUE8waKLyI2QKkJ2rSo6Y
    prettyprinter-1.7.1-890hJtP71KxJCLiD1l5JnX process-1.6.19.0
    safe-exceptions-0.1.7.4-BGySaU8uJj39VCxO5h0Lp3
    sqlite-simple-0.4.19.0-4lfN9MLoGcgKpl6bJV4Tf8 text-2.0.2
    unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

